yakumo.glance

Package yakumo :: Package glance |
[hide private]
[frames] | no frames]

# Package glance

source code

Submodules | [hide private]
yakumo.glance.v1: Sub client class for Glance API v1 yakumo.glance.v1.image: Resource class and its manager for images in Image V1 API yakumo.glance.v2: Sub client class for Glance API v2 yakumo.glance.v2.image: Resource class and its manager for images in Image V2 API yakumo.glance.v2.image_member: Resource class and its manager for image members in Image V2 API

Variables | [hide private]
| __package__ = `None`